@@ -17,7 +17,8 @@
 #'        conv_interval    = 1, 
 #'        mult_vars        = NULL,
 #'        mean_center_mult = FALSE,
-#'        standardize      = FALSE)
+#'        standardize      = FALSE,
+#'        hybrid = FALSE)
 #' @param data The path to the directory where the data files are located, 
 #' or the name of the list containing each individual's time series. 
 #' Each file or matrix must contain one matrix 
@@ -71,6 +72,8 @@
 #' before being multiplied together. Defaults to FALSE. 
 #' @param standardize Logical. If TRUE, all variables will be standardized to have a mean of zero and a
 #' standard deviation of one. Defaults to FALSE. 
+#' @param hybrid Logical. If TRUE, enables hybrid-VAR models where both directed contemporaneous paths and contemporaneous 	
+#' covariances among residuals are candidate relations in the search space. Defaults to FALSE.
 #'  @details
 #'  In main output directory:
 #'  \itemize{
@@ -111,13 +114,13 @@ aggSEM <- function(data,
                    conv_interval    = 1, 
                    mult_vars        = NULL,
                    mean_center_mult = FALSE,
-                   standardize      = FALSE){
+                   standardize      = FALSE,
+                   hybrid = FALSE){
   
   ind      = NULL # appease CRAN check
   grp      = NULL # appease CRAN check
   sub_spec = NULL # appease CRAN check
-  hybrid = FALSE
-  
+
 
   #Error check for hybrid
   if(hybrid & !ar){
