@@ -6,7 +6,7 @@
 #' information.
 #' @return Lists associated with coefficients, fit indices, etc.
 #' @keywords internal 
-indiv.search <- function(dat, grp, ind){
+indiv.search <- function(dat, grp, ind, hybrid){
   
   if (!dat$agg){
     ind$ind_paths   <-  vector("list", dat$n_subj)
@@ -15,6 +15,12 @@ indiv.search <- function(dat, grp, ind){
     ind <- NULL
   }
   
+  if(!hybrid){
+    elig_paths   = dat$candidate_paths
+  } else{
+    elig_paths   = c(dat$candidate_paths, dat$candidate_corr)
+  }
+  
   status   <- list()
   fits     <- list()
   coefs    <- list()
@@ -23,6 +29,8 @@ indiv.search <- function(dat, grp, ind){
   vcovfull <- list()
   plots    <- list()
   syntax   <- list()
+  psi      <- list()
+  psiunstd <- list()
   
   n_ind    <- ifelse(dat$agg, 1, dat$n_subj) 
   
@@ -43,13 +51,15 @@ indiv.search <- function(dat, grp, ind){
       writeLines(paste0("individual-level search, subject ", k, " (", names(dat$ts_list)[k],")"))
     }
     
+    
+    
     ind_spec <- search.paths(base_syntax  = dat$syntax, 
                              fixed_syntax = c(grp$group_paths, 
                                               ind$sub_paths[[k]]),
                              add_syntax   = character(),
                              n_paths      = 0,
                              data_list    = data_list,
-                             elig_paths   = dat$candidate_paths,
+                             elig_paths   = elig_paths,
                              prop_cutoff  = NULL,
                              n_subj       = 1,
                              chisq_cutoff = qchisq(.99, 1)
@@ -74,7 +84,7 @@ indiv.search <- function(dat, grp, ind){
                                add_syntax   = ind_spec$add_syntax,
                                n_paths      = ind_spec$n_paths,
                                data_list    = data_list,
-                               elig_paths   = dat$candidate_paths,
+                               elig_paths   = elig_paths,
                                prop_cutoff  = NULL,
                                n_subj       = 1,
                                chisq_cutoff = 0)
@@ -102,23 +112,28 @@ indiv.search <- function(dat, grp, ind){
     vcovfull[[k]]   <- s10$ind_vcov_full
     plots[[k]]  <- s10$ind_plot
     syntax[[k]] <- c(dat$syntax,  grp$group_paths, ind$sub_paths[[k]])
+    psi[[k]]      <- s10$ind_psi
+    psiunstd[[k]] <- s10$ind_psi_unstd
   }
   
   if (dat$agg){
     names(status) <- names(fits) <- names(coefs) <- 
-      names(betas) <- names(vcov) <- names(plots) <- "all"
+      names(betas) <- names(vcov) <- names(plots) <- names(psi) <- names(psiunstd) <-"all"
     # } else if (ind$n_ind_paths[k] > 0 & !dat$agg){
     #   names(status) <- names(fits) <- names(coefs) <- 
     #     names(betas) <- names(vcov) <- names(plots) <- names(dat$ts_list)
   } else {
     names(status) <- names(fits) <- names(coefs) <- 
-      names(betas) <- names(vcov) <- names(vcovfull) <- names(plots) <- names(dat$ts_list)
+      names(betas) <- names(vcov) <- names(vcovfull) <- names(plots) <- 
+      names(psi) <- names(psiunstd) <- names(dat$ts_list)
   }
   
   res <- list("status" = status,
               "fits"   = fits,
               "coefs"  = coefs,
               "betas"  = betas,
+              "psi"     = psi,
+              "psiunstd" = psiunstd,
               "vcov"   = vcov,
               "vcovfull"   = vcovfull,
               "plots"  = plots,
